configurationtools.verify_abjad_user_config_file
================================================

.. autofunction:: abjad.tools.configurationtools.verify_abjad_user_config_file.verify_abjad_user_config_file
